PyInduct
========

.. image:: https://img.shields.io/travis/pyinduct/pyinduct.svg
    :target: https://travis-ci.org/pyinduct/pyinduct

.. image:: https://readthedocs.org/projects/pyinduct/badge
    :target: http://pyinduct.rtfd.io

.. image:: https://codecov.io/gh/pyinduct/pyinduct/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/pyinduct/pyinduct

.. image:: https://img.shields.io/pypi/v/pyinduct.svg
    :target: https://pypi.python.org/pypi/pyinduct


PyInduct is a python toolbox for control and observer design for infinite dimensional systems.

* **Documentation**: https://pyinduct.readthedocs.org.
* **Bug Reports**: https://github.com/pyinduct/pyinduct/issues

PyInduct supports easy simulation of common distributed parameter systems using
ready-to-go FEM implementations or custom modal approximations.
With the included eigenfunctions for parabolic problems up to 2nd order or
case-agnostic Lagrangian polynomials, automated controller and observer
approximation routines are provided.
The included visualization methods help verifying the controllers performance.
